.. :changelog:

History
-------

0.9.1 (2017-03-28)
++++++++++++++++++

* Python3 local module fixed issue with utf-8
* unpinned dependencies

0.4 (2016-03-02)
++++++++++++++++++

* plaintexts are now returned as strings not as bytes

0.3 (2016-03-02)
++++++++++++++++++

* BREAKING CHANGE: introduced new semantics for Secret and a new StrictSecret
